import os
import psutil
from modules.base_module import BaseModule

class SystemInfoModule(BaseModule):

    def get_display_text(self):
        lines = []

        # CPU temperature
        try:
            with open("/sys/class/thermal/thermal_zone0/temp", "r") as f:
                temp_str = f.read()
            cpu_temp = round(int(temp_str) / 1000.0, 1)
            lines.append(f"CPU Temp: {cpu_temp}°C")
        except FileNotFoundError:
            lines.append("CPU Temp: N/A")

        # CPU usage
        cpu_usage = psutil.cpu_percent(interval=0.2)
        lines.append(f"CPU Usage: {cpu_usage}%")

        # Memory usage
        mem = psutil.virtual_memory()
        mem_used = round(mem.used / (1024 * 1024))
        mem_total = round(mem.total / (1024 * 1024))
        lines.append(f"Mem: {mem_used}/{mem_total}MB ({mem.percent}%)")

        return "\n".join(lines)
